@@ -1,4 +1,4 @@
-use Test::More;
+use Test::More tests=>1;
 use strict;
 use Tcl::Tk;
 
@@ -13,3 +13,5 @@ Tcl::Tk::Tkwidget::treectrl::Treectrl_Init($int);
 $int->source('../tests/all.tcl');
 
 ok(1);
+
+done_testing();
